@@ -263,6 +263,10 @@ class NestBase(object):
     def weather(self):
         return Weather(self._weather, self._local_time)
 
+    @property
+    def serial(self):
+        return self._serial
+
     @property
     def name(self):
         return self._serial
@@ -298,7 +302,7 @@ class Device(NestBase):
 
     @property
     def structure(self):
-        return Structure(self._link['structure'].lstrip('structure.'),
+        return Structure(self._link['structure'].split('.')[-1],
                          self._nest_api, self._local_time)
 
     @property
@@ -504,6 +508,257 @@ class Device(NestBase):
         self._set('device', data)
 
 
+class ProtectDevice(NestBase):
+    @property
+    def _device(self):
+        return self._nest_api._status['topaz'][self._serial]
+
+    @property
+    def _repr_name(self):
+        if self.name:
+            return self.name
+
+        return self.where
+
+    @property
+    def structure(self):
+        return Structure(self._device['structure_id'],
+                         self._nest_api, self._local_time)
+
+    @property
+    def where(self):
+        if 'where_id' in self._device:
+            return self.structure.wheres[self._device['where_id']]
+
+    @property
+    def auto_away(self):
+        return self._device['auto_away']
+
+    @property
+    def battery_health_state(self):
+        return self._device['battery_health_state']
+
+    @property
+    def battery_level(self):
+        return self._device['battery_level']
+
+    @property
+    def capability_level(self):
+        return self._device['capability_level']
+
+    @property
+    def certification_body(self):
+        return self._device['certification_body']
+
+    @property
+    def co_blame_duration(self):
+        if 'co_blame_duration' in self._device:
+            return self._device['co_blame_duration']
+
+    @property
+    def co_blame_threshold(self):
+        if 'co_blame_threshold' in self._device:
+            return self._device['co_blame_threshold']
+
+    @property
+    def co_previous_peak(self):
+        if 'co_previous_peak' in self._device:
+            return self._device['co_previous_peak']
+
+    @property
+    def co_sequence_number(self):
+        return self._device['co_sequence_number']
+
+    @property
+    def co_status(self):
+        return self._device['co_status']
+
+    @property
+    def component_als_test_passed(self):
+        return self._device['component_als_test_passed']
+
+    @property
+    def component_co_test_passed(self):
+        return self._device['component_co_test_passed']
+
+    @property
+    def component_heat_test_passed(self):
+        return self._device['component_heat_test_passed']
+
+    @property
+    def component_hum_test_passed(self):
+        return self._device['component_hum_test_passed']
+
+    @property
+    def component_led_test_passed(self):
+        return self._device['component_led_test_passed']
+
+    @property
+    def component_pir_test_passed(self):
+        return self._device['component_pir_test_passed']
+
+    @property
+    def component_smoke_test_passed(self):
+        return self._device['component_smoke_test_passed']
+
+    @property
+    def component_temp_test_passed(self):
+        return self._device['component_temp_test_passed']
+
+    @property
+    def component_us_test_passed(self):
+        return self._device['component_us_test_passed']
+
+    @property
+    def component_wifi_test_passed(self):
+        return self._device['component_wifi_test_passed']
+
+    @property
+    def creation_time(self):
+        return self._device['creation_time']
+
+    @property
+    def description(self):
+        return self._device['description']
+
+    @property
+    def device_external_color(self):
+        return self._device['device_external_color']
+
+    @property
+    def device_locale(self):
+        return self._device['device_locale']
+
+    @property
+    def fabric_id(self):
+        return self._device['fabric_id']
+
+    @property
+    def factory_loaded_languages(self):
+        return self._device['factory_loaded_languages']
+
+    @property
+    def gesture_hush_enable(self):
+        return self._device['gesture_hush_enable']
+
+    @property
+    def heads_up_enable(self):
+        return self._device['heads_up_enable']
+
+    @property
+    def home_alarm_link_capable(self):
+        return self._device['home_alarm_link_capable']
+
+    @property
+    def home_alarm_link_connected(self):
+        return self._device['home_alarm_link_connected']
+
+    @property
+    def home_alarm_link_type(self):
+        return self._device['home_alarm_link_type']
+
+    @property
+    def hushed_state(self):
+        return self._device['hushed_state']
+
+    @property
+    def installed_locale(self):
+        return self._device['installed_locale']
+
+    @property
+    def kl_software_version(self):
+        return self._device['kl_software_version']
+
+    @property
+    def latest_manual_test_cancelled(self):
+        return self._device['latest_manual_test_cancelled']
+
+    @property
+    def latest_manual_test_end_utc_secs(self):
+        return self._device['latest_manual_test_end_utc_secs']
+
+    @property
+    def latest_manual_test_start_utc_secs(self):
+        return self._device['latest_manual_test_start_utc_secs']
+
+    @property
+    def line_power_present(self):
+        return self._device['line_power_present']
+
+    @property
+    def night_light_continuous(self):
+        if 'night_light_continuous' in self._device:
+            return self._device['night_light_continuous']
+
+    @property
+    def night_light_enable(self):
+        return self._device['night_light_enable']
+
+    @property
+    def ntp_green_led_enable(self):
+        return self._device['ntp_green_led_enable']
+
+    @property
+    def product_id(self):
+        return self._device['product_id']
+
+    @property
+    def replace_by_date_utc_secs(self):
+        return self._device['replace_by_date_utc_secs']
+
+    @property
+    def resource_id(self):
+        return self._device['resource_id']
+
+    @property
+    def smoke_sequence_number(self):
+        return self._device['smoke_sequence_number']
+
+    @property
+    def smoke_status(self):
+        return self._device['smoke_status']
+
+    @property
+    def software_version(self):
+        return self._device['software_version']
+
+    @property
+    def spoken_where_id(self):
+        return self._device['spoken_where_id']
+
+    @property
+    def steam_detection_enable(self):
+        return self._device['steam_detection_enable']
+
+    @property
+    def thread_mac_address(self):
+        return self._device['thread_mac_address']
+
+    @property
+    def where_id(self):
+        return self._device['where_id']
+
+    @property
+    def wifi_ip_address(self):
+        return self._device['wifi_ip_address']
+
+    @property
+    def wifi_mac_address(self):
+        return self._device['wifi_mac_address']
+
+    @property
+    def wifi_regulatory_domain(self):
+        return self._device['wifi_regulatory_domain']
+
+    @property
+    def wired_led_enable(self):
+        return self._device['wired_led_enable']
+
+    @property
+    def wired_or_battery(self):
+        return self._device['wired_or_battery']
+
+
 class Structure(NestBase):
     @property
     def _structure(self):
@@ -528,10 +783,16 @@ class Structure(NestBase):
 
     @property
     def devices(self):
-        return [Device(devid.lstrip('device.'), self._nest_api,
+        return [Device(devid.split('.')[-1], self._nest_api,
                        self._local_time)
                 for devid in self._structure['devices']]
 
+    @property
+    def protectdevices(self):
+        return [ProtectDevice(topazid.split('.')[-1], self._nest_api,
+                              self._local_time)
+                for topazid in self._nest_api._status['topaz']]
+
     @property
     def dr_reminder_enabled(self):
         return self._structure['dr_reminder_enabled']
@@ -734,9 +995,14 @@ class Nest(object):
 
     @property
     def devices(self):
-        return [Device(devid.lstrip('device.'), self, self._local_time)
+        return [Device(devid.split('.')[-1], self, self._local_time)
                 for devid in self._status['device']]
 
+    @property
+    def protectdevices(self):
+        return [ProtectDevice(topazid.split('.')[-1], self, self._local_time)
+                for topazid in self._status['topaz']]
+
     @property
     def structures(self):
         return [Structure(stid, self, self._local_time)
